@@ -16,9 +16,11 @@ class DatabaseTestCase(unittest.TestCase):
         init_sqlalchemy(self.engine)
         if self.create_tables:
             meta.metadata.create_all()
+        super(DatabaseTestCase, self).setUp()
 
     def tearDown(self):
         transaction.abort()
         if self.create_tables:
             meta.metadata.drop_all()
         self.engine.dispose()
+        super(DatabaseTestCase, self).tearDown()
